<?php
/*************************
  Copyright (c) 2004-2013 TinyWebGallery 
  written by Michael Dempfle
  
  This program is free software; you can redistribute it and/or modify  
  it under the terms of the TinyWebGallery license (based on the GNU
  General Public License as published by the Free Software Foundation;  
  either version 2 of the License, or (at your option) any later version. 
  See license.txt for details.

  Generated by TWG admin
**********************************************/

/*
This is the basic administration file created by TWG admin.

If you want to configure TWG in more detail you can copy aditional settings from
the config.php to this file.

PLEASE NOTE: If you copy additional settings to this file you should NOT use the
frontend of TWG admin anymore because this file is generated if you save it there!

I have stored the most important settings for TWG here - config.php has around 400
different settings where most of the settings shown here, can be configured in more
detail + many more options are available! e.g. email notification ...
Please check the config.php if you want to adapt one of the settings to your needs!
*/
/** ensure this file is being included by a parent file */
defined( '_VALID_TWG' ) or die( 'Direct Access to this location is not allowed.' );

$privatepassword= 'test';                 // (String) To protect a gallery with a password you have to create an empty file with the name 'private.txt' in the directory you want to protect. If you want to protect a gallery with a different password you have to enter the password in the 'private.txt' file.
$browser_title_prefix= '[[sn]]';  // (String) This is the title which is shown in the browser title - you may change this to the name of your gallery
$default_gallery_title= '[[site_desc]]'; // (String) This is the default title shown on the main page if no real $lang_titel is specified in the language file. If you want to have different titles for a language please adapt the language files!
$skin= '';                                // (String) As default no skin is used - in the download  are 'black','green','transparent','winter' and 'newyork'  . All other style settings are still valid (check how-to 9). Some of the skin have a background! Check the Skins how-to to create your own skin or look in the forum of TWG - there is a skins section. if you change the skin you have to delete the *.slide.jpg images in the cache folder!
$icon_set= 'default';                     // (Number) New 1.7.5.1 - You can choose different icons sets. Some skins have their own icon set. You have to change this in the skin then!
$iframe_height_ie= '99%';                 // (String) If the height of iframes are smaller then 500px ie does not display them right - you have to define the heigth for ie that is used - normally this is around 4-5 pixel less then the height you have defined in your iframe - best is to have the color of your site the same bottom row
$show_border= 'TRUE';                     // new 1.2 - By default there is a border around TWG. If you integrate TWG is most of the time looks nicer if the left,right and bottom border are removed. This value can be set with url parameters too (twg_withborder=true or twg_noborder=true). This setting is cached in the session. You have to close all browser to see the changes!. Valid values 'TRUE' and 'FALSE';
$cache_dirs= false;                       // (true/false) content of directories are cached in the session - you can disable this if you have lots of image updates or are testing TWG while uploading.
$show_twg_logo_if_registered= false;      // (true/false) You can register and still show the TWG image if you like to support TWG
$enable_basic_seo= false;                 // New 2.0 - (true/false) This setting enables basic seo support for the thumbnail and the detail page. Please read the updated howto 44! before you enable this!

/* This section defines how the images are displayed - please delete the cache if you change image sizes  */
$menu_x= 4;                               // (Number) Number of albums which are shown in a row on the overview page.
$menu_y= 3;                               // (Number) Number of rows on the overview page.
$autodetect_maximum_thumbnails= true;     // (true/false) twg tries to display as much thumbnails as possible without creating scrollbars - is turned off in low bandwidth mode!
  $thumbnails_x= 6;                       // (Number) Number of images in a row on the thumbnail page.
  $thumbnails_y= 4;                       // (Number) Number of images in a column on the thumbnail page.
$number_top10= 13;                        // (Number) Number of images that are shown in the top views page. The existing calculation (13) works nice with the existing layout; The last row of the top x is alwys filled - therefore more then number_top10 images can be shown!
$small_pic_size= 400;                     // (Number) max pic size - please read the description of $use_small_pic_size_as_height (at the end) before you set this!
$resize_only_if_too_big= false;           // (true/false)  If images are equal or smaller they are not resized if true. You can save disk space if you set this to true and resize all pictures with an external program before uploading. watermarks are not generated on his images becasuse the are not touched at all! if you need them - please insert them by yourself because you wanted to keep the quality of the images.
$use_small_pic_size_as_height= true;      // (true/false)  use small_pic_size as height! - the small pic size restricts the picture to a maximum height and width of small_pic_size - therefore vertical and horizontal images have the same maximum side length. If you set this switch to true the size is used as maximum height. vertical images are then smaller then horizontal - but when you watch the images the navigation does not jump to the bottom if a vertical image is coming - If you use this please decrease the picture size by ~1/3 to get the vertical images in the same size as before (and delete the cache!!). The cross fade slideshow does appear smaller because the horizontal images are here still as big as the vertical ones.
$thumb_pic_size= 120;                     // (Number) The thumbnail size - check the $show_clipped_images description. If this is set true the thumbnails appear bigger
  $strip_thumb_pic_size= 100;             // (Number)  You can show the thumbs for the big navigation in a different size then on the thumbnail page! Does only work if clipped images are used.
$menu_pic_size_x= 120;                    // (Number) Width of the gallery overview pictures -  has to be dividable by 2 if using $show_colage=true; if $show_colage=false; please use the same scale as the pictures have to get the nicest results.
$menu_pic_size_y= 120;                    // (Number) Height of the gallery overview pictures -  has to be dividable by 2 if using $show_colage=true; if $show_colage=false; please use the same scale as the pictures have to get the nicest results.
$show_clipped_images= true;               // (true/false) Clipped images in the thumbnail view - all images will be shown as squares - if you change this - delete all thumbnails in the cache!!! The size of the images (x and y) will be $thumb_pic_size! remember - all thumbnails are squares then on the detail page you cannot see if a image is horizontal or vertical. remove all thumbnails from the cache folder after changing this!
$show_colage= true;                       // (true/false) Shows collage on the main page or the 1st image - you have to change the size of some preset images!
$use_random_image_for_folder= true;       // (true/false) If true a random image of this folder is picked for the collage or the image which is shown in a folder icon.
$folder_effect= 'fade';                   // (String) There are 3 effects for the main gallery view 'fade', 'gray' and  'change' (change the images with another from the directory on mouseover!) - if you don't want an effect use '' or 'none' - this effects looks best under ie - ff does some flickering in modus fade! - gray only works for ie (fade effect in ff as backup) - fade only for ie and ff - change for all browsers!
$skip_thumbnail_page= false;              // (true/false) Skip thumbnail page - if you set this to true, the thumbnail page is not displayed - be careful if you have subdirectories some levels cannot be displayed if a level before has pictures as well (like the demo) - the up button does always jump to the overview page!
$auto_skip_thumbnail_page= true;          // (true/false) If you set this to true the thumbnail page is only shown if you have more then numberpics (=images in the thumbsstrip in the directory). Why show an overview if all images are shown on the next page anyway ;) - false shows the thumbspage everytime. If the big navigation is not shown the thumbspage is shown allways.
$autorotate_images= '';                   // (String) ('','normal','invert') TWG can autodetect the orientation of images if your camera set this. The problem is that TWG does not know how you hold your camera. if you like no autorotation use '', If you want normal rotation use 'normal', If the images are all rotated 180 Degrees use 'invert'. I have set 'invert' as default because I always hold my camera like this + 2 other camera is tested did the same ;).
/* This section you can enable/disable show/hide main features of TWG */
$show_only_small_navigation= 'FALSE';     // ('TRUE','FALSE') 'TRUE' shows only the small navigation
  $default_big_navigation= 'DHTML';       // new 1.1 - There are 4 types of big Navigation - normal (value 'HTML'), dhtml (value 'DHTML'), flash (value 'FLASH') and htmlside ('HTML_SIDE')- the new HTML_SIDE version shows the thmbnails right and left next to the image! $numberofpics is the TOTAL number of images shown - 5 = 2 left, 2 right images -  The dhtml version does a lot of preloading - please do not use this if you have a lot of images in a directories or your expected users don't have fast connections 'HTML' = normal; 'DHTML' = dhtml version (much cooler :)). The flash  version is only "text free" in the registered version!
    $big_nav_pos= 'bottom';               // New 1.6 - valid entries are 'top' and 'bottom' - Displayed the thumb strip above or below the main image
    $numberofpics= 5;                     // (Number) Number of pictures that are displayed in the thumbnail strip off the image page - only 3,5,7 and 9 are tested - more does not make sense I would say :) !! The number has to be uneven!
    $autodetect_noscoll= true;            // (true/false) if you have less then $numberofpics images you don't need to scroll at all - if you set this to true the thumbs below are static no mater which one you select (the actual thumb in not below the image anymore!)
    $use_nonscrolling_dhtml= false;       // (true/false) if you set this to true the dhtml thumbsbar is not scrolling anymore - it is simply moving when you click on an thumbs - it looks like the html solution but is much faster - The reason I implemented this is because if you use  $use_dynamic_background=true the scroller does work pretty bad - therefore if you set $use_dynamic_background to true automatically the option is set to true!
$show_comments= true;                     // (true/false) enable comments and shows them below the pictures !!  - if you set this to false make sure that the $topx_default does not point to comments
$show_login= true;                        // (true/false) enables/disables the login button in the right upper corner
$show_optionen= true;                     // (true/false) enables/disables the options button in the right upper corner on the details page
$show_new_window= true;                   // (true/false) enables/disables the 'new window' button in the right upper corner and in the options pane.
$enable_download= true;                   // (true/false) enable download of original files
$show_image_rating= true;                 // (true/false) Enables the rating of images
$show_search= true;                       // (true/false) shows the search
$show_public_admin_link= true;            // (true/false) enables disables the link to the admin area !
$show_slideshow= true;                    // (true/false) Enables / disables the slideshow functionality of TWG
  $twg_slide_type= 'TRUE';                // new 1.1 - define the default slideshow type - 'TRUE' is the cross fade version, 'FALSE' the normal version, 'FULL' the maximized version!
  $twg_slideshow_time= '5';               // new 1.1 - Defines the default slideshowtime
$show_captions= true;                     // (true/false) you can hide the menu element to enter a caption
$show_counter= true;                      // (true/false) show the counter - if not shown the counter is still counting!
$show_image_rating= true;                 // (true/false) Enables the rating of images
$show_help_link= true;                    // (true/false) Shows the help link
$show_enhanced_file_infos= true;          // (true/false) Shows the 'Info' of an image in the menu
$show_rotation_buttons= true;             // (true/false) show the rotation buttons  ; true - shows them; false - hides them - if the rotation function cannot be detected by function_exists the rotation buttons are not shown at all!
$show_bandwidth_icon= true;               // (true/false) you can hide the bandwidth icon if you like- true: shows it - false hides it (test is still done!)
$show_topx= true;                         // (true/false) Show the topx or hide it - make sure to have at least one of the topx options enabled!
$show_tags= true;                         // (true/false) Show the top tags - the search for tags and the posiblility to enter tags at the detail page when logged in.
$open_in_maximized_view= false;           // (true/false) opens the image in the maximized view as it can be done in the menu - $open_download_in_new_window and open_as_popup are ignored!
$disable_tips= false;                     // (true/false) enables to show a small tip on all pages   
$enable_album_tree= true;                 // (true/false) You can display an explorer like album tree on the left side - this is a bonus feature for registered users :).
$sort_images_ascending= true;             // (true/false) true: sorts the images ascending; false: descending  (date and filename!)
  $sort_by_date= false;                   // (true/false) sorts the images by name if set to false - if set to true it tries to read the image exif data first - if  this fails it uses the filetime to sort! - read the faq for the settings you need on your server to get exif data! if you have a lot of images in a dir setting this to true could slow down the gallery because the data is read every time  a directory is read
    $sort_by_filedate= false;             // (true/false) uses the last modified file date and is not searching for exif data. If false is looks for exif data and uses the file time only if no exif data is available.
$sort_albums= true;                       // (true/false) sometimes sorting is not wanted - I cannot tell how the sorting will be - but maybe exactly how you like it (most of the time it is the order the directories are created!)
  $sort_albums_ascending= true;           // (true/false) true: sorts the albums ascending (if $sort_album_by_date true = newest first); false: descending () - directory struture is cached - close your browser once after changing this parameter!
    $sort_album_by_date= false;           // (true/false) enables sorting of folders by last modified date - directory structure is cached - close your browser once after changing this parameter!
/* This section is responsible for the watermark stuff - please delete the cache if you change watermarks */
$print_text= false;                       // (true/false) you can print some text on the lower left corner to protect your images  or at least make it a little bit harder to copy it without doing anything :) if you change this setting please delete the cache folder - otherwise generated images are not changed.
$print_text_original= false;              // (true/false) does print the text on the original as well - $enable_direct_download has to be set to false!!!
  $text= 'powered by TinyWebGallery';     // The watermark text. 
$print_watermark= true;                   // (true/false) you can make a watermark on the images to protect your images or at least make it a little bit harder to copy it without doing anything :) if you change this setting please delete the cache folder - otherwise generated images are not changed. Please read the description of the parameters that belong to the watermark to get best results!
$print_watermark_original= false;         // (true/false) does print the watermark on the original as well - $enable_direct_download has to be set to false!!!
  $watermark_small= 'buttons/watermark_small.png'; // new 1.1 - this is the watermark that is used on the detail and slideshow images - can be jpg or png - png gives better results
  $watermark_small= 'buttons/watermark_small.png'; // new 1.1 - this is the watermark that is used on the detail and slideshow images - can be jpg or png - png gives better results
$position= 7;                             // new 1.1 you can define the location of the watermark with this setting (top:  1  2  3, middle: 4  5  6, bottom: 7  8  9

/*
This is a helper variable for reloading your extra settings. If you add a new parameter manually
you have to add it to this variable too - otherwise it will be removed if the config
is changed by TWG admin! $ and " have to be escaped!!
*/
$youremail = '[[admin_email]]';
$admin_email='[[admin_email]]';
$additional="";
/* extra parameters set in the additional page in the TWG admin */


// PLEASE ONLY ADD PARAMETERS HERE IF YOU DON'T USE TWG ADMINISTRATION. OTHERWISE THE PARAMETERS 
// GET REMOVED THE NEXT TIME YOU SAVE THE SETTINGS THERE
// PLEASE ADD YOUR SETTINGS IN THE FREE TEXT FIELD OF THE CONFIG THEN.

?>